%define debug_package %{nil}

%global         with_python2 0

%if 0%{?fedora} || 0%{?centos} >= 7
%global         with_python3 1
%else
%global         with_python3 0
%endif

%if 0%{?centos}0%{?amzn} == 70
%define python3_pkgversion 36
%endif

Name:           lz4
Version:        4.0.1
Release:        1%{?dist}
URL:            https://github.com/%{name}
Summary:        LZ4 Bindings for Python
License:        BSD
Source:         https://files.pythonhosted.org/packages/source/l/%{name}/%{name}-%{version}.tar.gz

BuildRequires:  lz4-devel

%description
Python bindings for the lz4 compression library.

%if 0%{?with_python2}
%package -n python2-%{name}
BuildRequires:  python2-devel
BuildRequires:  python2-setuptools
BuildRequires:  python2-nose
Summary:        LZ4 Bindings for Python 2
%{?python_provide:%python_provide python2-%{name}}

%description -n python2-%{name}
Python 2 bindings for the lz4 compression library.
%endif

%if 0%{?with_python3}
%package -n python%{python3_pkgversion}-%{name}
Summary:        LZ4 Bindings for Python 3
BuildRequires:  python%{python3_pkgversion}-devel
BuildRequires:  python%{python3_pkgversion}-setuptools
BuildRequires:  python%{python3_pkgversion}-nose
%{?python_provide:%python_provide python%{python3_pkgversion}-%{name}}

%description -n python%{python3_pkgversion}-%{name}
Python 3 bindings for the lz4 compression library.
%endif

%prep
%autosetup -n %{name}-%{version} -p1

# Remove bundled lz4 as we're building against system lib
#rm src/lz4*.[ch]

%build
%if 0%{?with_python2}
%py2_build
%endif
%if 0%{?with_python3}
%py3_build
%endif

%install
%if 0%{?with_python2}
%py2_install
%endif
%if 0%{?with_python3}
%py3_install
%endif

# Fix permissions on shared objects
%if 0%{?with_python2}
find %{buildroot}%{python2_sitearch} -name '%{name}*.so' \
    -exec chmod 0755 {} \;
%endif

%if 0%{?with_python3}
find %{buildroot}%{python3_sitearch} -name '%{name}*.so' \
    -exec chmod 0755 {} \;
%endif

%if "x1" == "x"
%check
# First we'll just try importing
%if 0%{?with_python2}
PYTHONPATH=$RPM_BUILD_ROOT%{python2_sitearch} %{__python2} -c "import %{name}"
%endif
%if 0%{?with_python3}
PYTHONPATH=$RPM_BUILD_ROOT%{python3_sitearch} %{__python3} -c "import %{name}"
%endif

# And also run the tests included
%if 0%{?with_python2}
%{__python2} setup.py test
%endif
%if 0%{?with_python3}
%{__python3} setup.py test
%endif
%endif

%if 0%{?with_python2}
%files -n python2-%{name}
# Unfortunately there's no LICENSE/COPYING file included.
# Issue filed upstream:
# https://github.com/steeve/python-lz4/issues/38
%doc README.rst
%{python2_sitearch}/%{name}*
%endif

%if 0%{?with_python3}
%files -n python%{python3_pkgversion}-lz4
%doc README.rst
%{python3_sitearch}/lz4*
%endif

%changelog
* Sun May 22 2022 Lawrence R. Rogers <lrr@cert.org> 4.0.1-1
* Release 4.0.1-1
	Version 4.0.1

* Thu Nov 25 2021 Lawrence R. Rogers <lrr@cert.org> 3.1.10-1
* Release 3.1.10-1
	Version 3.1.10

* Tue Jan 19 2021 Lawrence R. Rogers <lrr@cert.org> 3.1.3-1
* Release 3.1.3-1
	Version 3.1.3

* Fri Jan 15 2021 Lawrence R. Rogers <lrr@cert.org> 3.1.2-1
* Release 3.1.2-1
	Version 3.1.2

* Wed Nov 18 2020 Lawrence R. Rogers <lrr@cert.org> 3.1.1-1
* Release 3.1.1-1
	Version 3.1.1

* Tue Jun  9 2020 Lawrence R. Rogers <lrr@cert.org> 3.1.0-1
* Release 3.1.0-1
	Version 3.1.0

* Sat Dec 28 2019 Lawrence R. Rogers <lrr@cert.org> 3.0.2-1
* Release 3.0.2-1
	Version 3.0.2

* Sun May 19 2019 Lawrence R. Rogers <lrr@cert.org> 0.10.0-1
* Release 0.10.0-1
	Version 0.10.0-1: Upgraded to 0.10.0

* Fri Mar 08 2019 Troy Dawson <tdawson@redhat.com> - 0.8.2-2
- Rebuilt to change main python from 3.4 to 3.6

* Tue Nov  8 2016 Orion Poplawski <orion@cora.nwra.com> - 0.8.2-1
- Update to 0.8.2
- Enable EPEL7 builds

* Tue Jul 19 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.8.1-2
- https://fedoraproject.org/wiki/Changes/Automatic_Provides_for_Python_RPM_Packages

* Wed Apr 27 2016 Jonathan Underwood <jonathan.underwood@gmail.com> - 0.8.1-1
- Update to 0.8.1
- Use new upstream URL
- Drop upstreamed patch
- Use PyPi source url with hash, for now

* Sun Feb 28 2016 Jonathan Underwood <jonathan.underwood@gmail.com> - 0.7.0-6
- Spec file cleanup
- Add use of python_provide macro
- Remove python 3 conditional build - always build
- Use standard python packaging build and install macros

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 0.7.0-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Fri Nov 06 2015 Robert Kuska <rkuska@redhat.com> - 0.7.0-4
- Rebuilt for Python3.5 rebuild

* Mon Jun 29 2015 Jonathan Underwood <jonathan.underwood@gmail.com> - 0.7.0-3
- Update patch to build against system libs and add compress_fast method
- Add BR for python[3]-nose
- Run bundled test in %%check

* Sat Jun 27 2015 Jonathan Underwood <jonathan.underwood@gmail.com> - 0.7.0-2
- Drop unneeded Requires for lz4
- Remove commented out cruft from spec
- Regenerate setup.py patch to use libraries=["lz4"]
- Remove bundled lz4 code in %%prep

* Sat Jun 27 2015 Jonathan Underwood <jonathan.underwood@gmail.com> - 0.7.0-1
- Build against system lz4 libs
- Rudimentary check to see if we can import the module

* Sat Jun 27 2015 Jonathan Underwood <jonathan.underwood@gmail.com> - 0.7.0-0.2
- Include README.rst in python3 package as well

* Sat Jun 27 2015 Jonathan Underwood <jonathan.underwood@gmail.com> - 0.7.0-0.1
- Fix permissions of shared objects to be 0755

* Sat Jun 27 2015 Jonathan Underwood <jonathan.underwood@gmail.com> - 0.7.0-0
- Initial package for Fedora

